@@ -4,6 +4,7 @@ the organization using cloudlift
 """
 import ipaddress
 import json
+from distutils.version import LooseVersion
 
 import boto3
 import dictdiffer
@@ -12,6 +13,7 @@ from click import confirm, edit, prompt
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError
 
+from cloudlift.version import VERSION
 from cloudlift.exceptions import UnrecoverableException
 from cloudlift.config import DecimalEncoder
 from cloudlift.config import print_json_changes
@@ -32,7 +34,7 @@ class EnvironmentConfiguration(object):
         self.dynamodb = session.resource('dynamodb')
         self.table = self._get_table()
 
-    def get_config(self):
+    def get_config(self, cloudlift_version=VERSION):
         '''
             Get configuration from DynamoDB
         '''
@@ -47,13 +49,25 @@ class EnvironmentConfiguration(object):
                     'configuration'
                 ]
             )
-            return configuration_response['Item']['configuration']
+            existing_configuration = configuration_response['Item']['configuration']
+            previous_cloudlift_version = existing_configuration.pop("cloudlift_version", None)
+            # print(f"Previous cloudlift version in environment config is {previous_cloudlift_version}")
+            if previous_cloudlift_version and LooseVersion(cloudlift_version) < LooseVersion(previous_cloudlift_version):
+                raise UnrecoverableException(f'Cloudlift Version {previous_cloudlift_version} was used to '
+                                             f'create this service. You are using version {cloudlift_version}, '
+                                             f'which is older and can cause corruption. Please upgrade to at least '
+                                             f'version {previous_cloudlift_version} to proceed.\n\nUpgrade to the '
+                                             f'latest version (Recommended):\n'
+                                             f'\tpip install -U cloudlift\n\nOR\n\nUpgrade to a compatible version:\n'
+                                             f'\tpip install -U cloudlift=={previous_cloudlift_version}')
+            return existing_configuration
         except ClientError:
             raise UnrecoverableException("Unable to fetch environment configuration from DynamoDB.")
         except KeyError:
             raise UnrecoverableException("Environment configuration not found. Does this environment exist?")
 
     def update_config(self):
+
         if not self._env_config_exists():
             self._create_config()
         self._edit_config()
@@ -131,45 +145,43 @@ class EnvironmentConfiguration(object):
         key_name = prompt("SSH key name")
         notifications_arn = prompt("Notification SNS ARN")
         ssl_certificate_arn = prompt("SSL certificate ARN")
-        environment_configuration = {
-            self.environment: {
-                "region": region,
-                "vpc": {
-                    "cidr": str(vpc_cidr),
-                    "nat-gateway": {
-                        "elastic-ip-allocation-id": nat_eip
-                    },
-                    "subnets": {
-                        "public": {
-                            "subnet-1": {
-                                "cidr": str(public_subnet_1_cidr)
-                            },
-                            "subnet-2": {
-                                "cidr": str(public_subnet_2_cidr)
-                            }
+        environment_configuration = {self.environment: {
+            "region": region,
+            "vpc": {
+                "cidr": str(vpc_cidr),
+                "nat-gateway": {
+                    "elastic-ip-allocation-id": nat_eip
+                },
+                "subnets": {
+                    "public": {
+                        "subnet-1": {
+                            "cidr": str(public_subnet_1_cidr)
                         },
-                        "private": {
-                            "subnet-1": {
-                                "cidr": str(private_subnet_1_cidr)
-                            },
-                            "subnet-2": {
-                                "cidr": str(private_subnet_2_cidr)
-                            }
+                        "subnet-2": {
+                            "cidr": str(public_subnet_2_cidr)
+                        }
+                    },
+                    "private": {
+                        "subnet-1": {
+                            "cidr": str(private_subnet_1_cidr)
+                        },
+                        "subnet-2": {
+                            "cidr": str(private_subnet_2_cidr)
                         }
                     }
-                },
-                "cluster": {
-                    "min_instances": cluster_min_instances,
-                    "max_instances": cluster_max_instances,
-                    "instance_type": cluster_instance_type,
-                    "key_name": key_name
-                },
-                "environment": {
-                    "notifications_arn": notifications_arn,
-                    "ssl_certificate_arn": ssl_certificate_arn
                 }
+            },
+            "cluster": {
+                "min_instances": cluster_min_instances,
+                "max_instances": cluster_max_instances,
+                "instance_type": cluster_instance_type,
+                "key_name": key_name
+            },
+            "environment": {
+                "notifications_arn": notifications_arn,
+                "ssl_certificate_arn": ssl_certificate_arn
             }
-        }
+        }, 'cloudlift_version': VERSION}
         self._set_config(environment_configuration)
         pass
 
@@ -177,10 +189,9 @@ class EnvironmentConfiguration(object):
         '''
             Open editor to update configuration
         '''
-
         try:
             current_configuration = self.get_config()
-
+            previous_cloudlift_version = current_configuration.pop('cloudlift_version', None)
             updated_configuration = edit(
                 json.dumps(
                     current_configuration,
@@ -200,10 +211,14 @@ class EnvironmentConfiguration(object):
                 ))
                 if not differences:
                     log_warning("No changes made.")
+                    updated_configuration['cloudlift_version']=VERSION
+                    self._set_config(updated_configuration)
+                    # self.update_cloudlift_version()
                 else:
                     print_json_changes(differences)
                     if confirm('Do you want update the config?'):
                         self._set_config(updated_configuration)
+                        # self.update_cloudlift_version()
                     else:
                         log_warning("Changes aborted.")
         except ClientError:
@@ -214,6 +229,8 @@ class EnvironmentConfiguration(object):
             Set configuration in DynamoDB
         '''
         self._validate_changes(config)
+        config['cloudlift_version'] = VERSION
+
         try:
             configuration_response = self.table.update_item(
                 TableName=ENVIRONMENT_CONFIGURATION_TABLE,
@@ -231,6 +248,14 @@ class EnvironmentConfiguration(object):
             raise UnrecoverableException("Unable to store environment configuration in DynamoDB.")
         pass
 
+    def update_cloudlift_version(self):
+        '''
+            Updates cloudlift version in service configuration
+        '''
+        print(f"setting cloudlift version to {VERSION}")
+        config = self.get_config(VERSION)
+        self._set_config(config)
+
     def _validate_changes(self, configuration):
         log_bold("\nValidating schema..")
         # TODO: add cidr etc validation
